import click
import sys
from urlchecker_bot import create_bot


@click.command(short_help="Runs url checker bot.")
@click.option(
    "--run",
    "-r",
    help="The bot operation mode to run.",
    show_default=True,
    default="status",
    type=click.Choice(["crawl", "status"]),
)
@click.option(
    "--sqlite", "-s", help="The path of the sqlite DB. (default: :memory:)"
)
@click.option("--nameserver", "-n", help="The IP of the DNS server.")
@click.option("--url", "-u", help="The url to check.")
@click.option("--domain", "-d", help="The domain to check.")
@click.option(
    "--configuration", "-f", help="The path of the configuration file."
)
def runUrlChecker(run, sqlite, nameserver, url, domain, configuration):

    # click.echo("Running url checker bot")
    mapping = {}
    if url:
        mapping["URL"] = url
        mapping["DOMAIN"] = ""
    if domain:
        mapping["DOMAIN"] = domain
        if not url:
            mapping["URL"] = ""
    if sqlite:
        mapping["SQLITE"] = sqlite
    if nameserver:
        mapping["NAMESERVER"] = nameserver
    bot = create_bot(cfgfile=configuration, mapping=mapping)
    return bot.run(run)


if __name__ == "__main__":
    sys.exit(runUrlChecker())
